@@ -1047,7 +1047,7 @@ reView_server <- function(old_bn,hfserie_name,lfserie_name,compare) {
 #' @importFrom utils packageVersion
 runapp_reView <- function(old_bn,hfserie_name,lfserie_name,compare) {
   if (!requireNamespace("shiny", quietly = TRUE) ||
-      packageVersion("shiny") < 1.5) {
+      packageVersion("shiny") < "1.5") {
     stop("In order to use the reView shiny app, shiny >= 1.5.0 is needed.\n",
          "Please run install.packages(\"shiny\")",
          call. = FALSE)
@@ -1139,15 +1139,12 @@ reView.reViewOutput <- function(object,
          compare = compare)
 }
 
-warning_reviewoutput <- warning_news_factory("The order of the reViewOutput object produced by reView has been reversed. See NEWS. This warning is displayed once in each R session.")
-
 #' @export
 reView.twoStepsBenchmark <- function(object,
                                      hfserie_name = NULL,
                                      lfserie_name = NULL,
                                      compare = TRUE) {
   if (NCOL(neither_outlier_nor_constant(object)) > 1) stop("This reviewing application is only for univariate benchmarks.", call. = FALSE)
-  warning_reviewoutput()
   runapp_reView(object,
                 reViewName(hfserie_name %||% object$call$hfserie),
                 reViewName(lfserie_name %||% object$call$lfserie),
@@ -1224,7 +1221,7 @@ rePort.reViewOutput <- function(object, output_file = NULL,
                                 lfserie_name = NULL,
                                 ...) {
   if (!requireNamespace("rmarkdown", quietly = TRUE) ||
-      packageVersion("rmarkdown") < 2.0) {
+      packageVersion("rmarkdown") < "2.0") {
     stop("In order to use the rePort function, rmarkdown >= 2.0.0 is needed.\n",
          "Please run install.packages(\"rmarkdown\")",
          call. = FALSE)
