@@ -3,7 +3,7 @@ library(disaggR)
 ui <- disaggR:::reView_ui()
 
 server <-  disaggR:::reView_server(twoStepsBenchmark(turnover,construction),
-                                   "turnover","construction",
+                                   as.symbol("turnover"),as.symbol("construction"),
                                    TRUE)
 
 shinyApp(ui = ui, server = server)
\ No newline at end of file
