@@ -7,7 +7,16 @@ skips <- function() {
             as.character(sessionInfo()[c("BLAS","LAPACK")]))
     )
   )
-  skip_if(packageVersion("ggplot2") < "3.5.0")
+  skip_if(
+    any(
+      grepl("atlas",
+            as.character(sessionInfo()[c("BLAS","LAPACK")]))
+    )
+  )
+  skip_if(packageVersion("ggplot2") < numeric_version("3.5.0"))
+  skip_if(getRversion() < numeric_version("4.5.0"))
+  skip_on_os("mac")
+  # Des problèmes dans vdiffr sur mac
 }
 
 # taken from the non exported of vdiffr
@@ -19,14 +28,7 @@ str_standardise <- function (s, sep = "-")  {
   s
 }
 
-expect_doppelganger <- function(title, fig) {
-  this_version <- paste0(title, "-", if (getRversion() < "4.4.0") "lt43" else "gt44")
-  other_version <- paste0(title, "-", if (getRversion() < "4.4.0") "gt44" else "lt43")
-  fig_name <- str_standardise(other_version)
-  file <- paste0(fig_name, ".svg")
-  testthat::announce_snapshot_file(name = file)
-  vdiffr::expect_doppelganger(this_version, fig)
-}
+expect_doppelganger <- vdiffr::expect_doppelganger
 
 test_that("function_if_it_isnt_one works", {
   expect_identical(function_if_it_isnt_one(seq_len),seq_len)
